
#!perl

# This file was automatically generated by Dist::Zilla::Plugin::Test::Map::Tube v0.08.

use strict; use warnings;
use utf8;
use Test::More;

eval "use Test::Map::Tube 0.15 tests => 3";
plan skip_all => "Test::Map::Tube 0.15 required" if $@;

use Map::Tube::Delhi;

ok_map(Map::Tube::Delhi->new);

ok_map_functions(Map::Tube::Delhi->new);

open (IN, "t/routes.txt") or die "Can't open routes file: $!\n"; my @routes = <IN>; close(IN);

ok_map_routes(Map::Tube::Delhi->new, \@routes);

